@@ -10,10 +10,12 @@ radius = openmc.stats.Discrete([10], [1])
 z_values = openmc.stats.Discrete([0], [1])
 
 # the distribution of source azimuthal angles values is a uniform distribution between 0 and 2 Pi
-angle = openmc.stats.Uniform(a=0., b=2* 3.14159265359)
+angle = openmc.stats.Uniform(a=0.0, b=2 * 3.14159265359)
 
 # this makes the ring source using the three distributions and a radius
-my_source.space = openmc.stats.CylindricalIndependent(r=radius, phi=angle, z=z_values, origin=(0.0, 0.0, 0.0))
+my_source.space = openmc.stats.CylindricalIndependent(
+    r=radius, phi=angle, z=z_values, origin=(0.0, 0.0, 0.0)
+)
 
 # sets the direction to isotropic
 my_source.angle = openmc.stats.Isotropic()
@@ -25,4 +27,4 @@ my_settings = openmc.Settings()
 
 my_settings.source = my_source
 
-my_settings.export_to_xml()
\ No newline at end of file
+my_settings.export_to_xml()
